LONG_TIMEOUT = 30.0   # For wifi scan
SHORT_TIMEOUT = 10.0   # For any other command

DEFAULT_MEROSS_HTTP_API = "https://iot.meross.com"
DEFAULT_MQTT_HOST = "mqtt.meross.com"
DEFAULT_MQTT_PORT = 443
DEFAULT_COMMAND_TIMEOUT = 10.0

